==> zio-aws-pinpoint_3-5.17.104.12-sources.jar: zio/aws/pinpoint/model/ListTagsForResourceRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class ListTagsForResourceRequest(resourceArn: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.ListTagsForResourceRequest = {
    import ListTagsForResourceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.ListTagsForResourceRequest
      .builder()
      .resourceArn(__string.unwrap(resourceArn): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.ListTagsForResourceRequest.ReadOnly =
    zio.aws.pinpoint.model.ListTagsForResourceRequest.wrap(buildAwsValue())
}
object ListTagsForResourceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.ListTagsForResourceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.ListTagsForResourceRequest =
      zio.aws.pinpoint.model.ListTagsForResourceRequest(resourceArn)
    def resourceArn: __string
    def getResourceArn: ZIO[Any, Nothing, __string] = ZIO.succeed(resourceArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.ListTagsForResourceRequest
  ) extends zio.aws.pinpoint.model.ListTagsForResourceRequest.ReadOnly {
    override val resourceArn: __string =
      zio.aws.pinpoint.model.primitives.__string(impl.resourceArn())
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.ListTagsForResourceRequest
  ): zio.aws.pinpoint.model.ListTagsForResourceRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-pinpoint_3-5.17.267.1-sources.jar: zio/aws/pinpoint/model/ListTagsForResourceRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class ListTagsForResourceRequest(resourceArn: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.ListTagsForResourceRequest = {
    import ListTagsForResourceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.ListTagsForResourceRequest
      .builder()
      .resourceArn(resourceArn: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.ListTagsForResourceRequest.ReadOnly =
    zio.aws.pinpoint.model.ListTagsForResourceRequest.wrap(buildAwsValue())
}
object ListTagsForResourceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.ListTagsForResourceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.ListTagsForResourceRequest =
      zio.aws.pinpoint.model.ListTagsForResourceRequest(resourceArn)
    def resourceArn: __string
    def getResourceArn: ZIO[Any, Nothing, __string] = ZIO.succeed(resourceArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.ListTagsForResourceRequest
  ) extends zio.aws.pinpoint.model.ListTagsForResourceRequest.ReadOnly {
    override val resourceArn: __string = impl.resourceArn(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.ListTagsForResourceRequest
  ): zio.aws.pinpoint.model.ListTagsForResourceRequest.ReadOnly = new Wrapper(
    impl
  )
}
